@@ -8,6 +8,7 @@ from .common.protocol import DEFAULT_SIMPLE_AGENT_NAME
 from .common.protocol import DEFAULT_UNIQUE_KEY_AGENT_NAME
 from loguru import logger
 import threading
+import psutil
 
 logger.remove()
 # logger.add(sys.stderr, level='DEBUG')
@@ -19,9 +20,19 @@ simple_agent = SimpleTopicAgent()
 
 @app.route('/')
 def index():
+    cpu_usage = psutil.cpu_percent()
+    mem_used_percent = psutil.virtual_memory()[2]
+    mem_used_gb = psutil.virtual_memory()[3]/1000000000
     resp = {
-        'UniqueKeyAgent': unique_key_agent.info(),
-        'SimpleAgent': simple_agent.info(),
+        'Info': {
+            'The CPU usage is: ': f'{cpu_usage}%',
+            'RAM memory used: ': f'{mem_used_percent}%',
+            'RAM Used (GB): ': f'{round(mem_used_gb, 2)}'
+        },
+        'Topics': {
+            'UniqueKeyAgent': unique_key_agent.info(),
+            'SimpleAgent': simple_agent.info(),
+        }
     }
     return jsonify(resp)
 
